# This spec file is derived from RHEL 9.1 GA package. It hopefully
# should get obsolete with RHEL 9.2 GA when libzmf-devel got included.
# Upstream: https://gitlab.com/redhat/centos-stream/rpms/libzmf
%global rhel_name libzmf
%global rhel_release 18
%global epel_release 1
%global _debugsource_template %{nil}

%global apiversion 0.0

Name: libzmf-epel
Version: 0.0.2
Release: 0.%{rhel_release}%{?dist}.%{epel_release}
Summary: A library for import of Zoner document formats

License: MPLv2.0
URL: http://wiki.documentfoundation.org/DLP/Libraries/libzmf
Source: http://dev-www.libreoffice.org/src/%{rhel_name}/%{rhel_name}-%{version}.tar.xz

BuildRequires: boost-devel
BuildRequires: doxygen
BuildRequires: gcc-c++
BuildRequires: help2man
BuildRequires: pkgconfig(cppunit)
BuildRequires: pkgconfig(icu-uc)
BuildRequires: pkgconfig(librevenge-0.0)
BuildRequires: pkgconfig(librevenge-generators-0.0)
BuildRequires: pkgconfig(librevenge-stream-0.0)
BuildRequires: pkgconfig(libpng)
BuildRequires: pkgconfig(zlib)
BuildRequires: make

%description
libzmf is library providing ability to interpret and import Zoner
document formats into various applications. Currently it only supports
Zoner Callisto/Draw v 4-5.

%package -n %{rhel_name}-devel
Summary: Development files for %{rhel_name}
Requires: %{rhel_name}%{?_isa} = %{version}

%description -n %{rhel_name}-devel
The %{rhel_name}-devel package contains libraries and header files for
developing applications that use %{rhel_name}.

%prep
%autosetup -n %{rhel_name}-%{version} -p1

%build
%configure --disable-silent-rules --disable-static --disable-werror
sed -i \
    -e 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' \
    -e 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' \
    libtool
%make_build

%install
%make_install
rm -f %{buildroot}/%{_libdir}/*.la
# we install API docs directly from build
rm -rf %{buildroot}/%{_docdir}/%{rhel_name}

# generate and install man pages
export LD_LIBRARY_PATH=%{buildroot}/%{_libdir}${LD_LIBRARY_PATH:+:${LD_LIBRARY_PATH}}
for tool in zmf2raw zmf2svg; do
    help2man -N -S '%{rhel_name} %{version}' -o ${tool}.1 %{buildroot}%{_bindir}/${tool}
done
install -m 0755 -d %{buildroot}/%{_mandir}/man1
install -m 0644 zmf2*.1 %{buildroot}/%{_mandir}/man1

# Remove files shipped in RHEL 9
rm -f $RPM_BUILD_ROOT%{_libdir}/%{rhel_name}-%{apiversion}.so.*
rm -rf $RPM_BUILD_ROOT{%{_bindir},%{_mandir}}

%ldconfig_scriptlets

%check
export LD_LIBRARY_PATH=%{buildroot}/%{_libdir}${LD_LIBRARY_PATH:+:${LD_LIBRARY_PATH}}
%make_build check || :

%files -n %{rhel_name}-devel
%doc ChangeLog
%{_includedir}/%{rhel_name}-%{apiversion}
%{_libdir}/%{rhel_name}-%{apiversion}.so
%{_libdir}/pkgconfig/%{rhel_name}-%{apiversion}.pc

%changelog
* Sat Dec 10 2022 Robert Scheck <robert@fedoraproject.org> - 0.0.2-0.18.el9.1
- Transformed libzmf-0.0.2-18.el9 into libzmf-epel to achieve the missing
  libzmf-devel package for EPEL 9 until it's available with RHEL 9.2
  Related: rhbz#2144658

* Mon Aug 09 2021 Mohan Boddu <mboddu@redhat.com> - 0.0.2-18
- Rebuilt for IMA sigs, glibc 2.34, aarch64 flags
  Related: rhbz#1991688

* Fri Apr 16 2021 Mohan Boddu <mboddu@redhat.com> - 0.0.2-17
- Rebuilt for RHEL 9 BETA on Apr 15th 2021. Related: rhbz#1947937

* Tue Jan 26 2021 Fedora Release Engineering <releng@fedoraproject.org> - 0.0.2-16
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Tue Jul 28 2020 Fedora Release Engineering <releng@fedoraproject.org> - 0.0.2-15
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Tue Jul 14 2020 Tom Stellard <tstellar@redhat.com> - 0.0.2-14
- Use make macros
- https://fedoraproject.org/wiki/Changes/UseMakeBuildInstallMacro

* Sat May 16 2020 Pete Walter <pwalter@fedoraproject.org> - 0.0.2-13
- Rebuild for ICU 67

* Wed Jan 29 2020 Fedora Release Engineering <releng@fedoraproject.org> - 0.0.2-12
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Fri Nov 01 2019 Pete Walter <pwalter@fedoraproject.org> - 0.0.2-11
- Rebuild for ICU 65

* Thu Jul 25 2019 Fedora Release Engineering <releng@fedoraproject.org> - 0.0.2-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Fri Feb 01 2019 Fedora Release Engineering <releng@fedoraproject.org> - 0.0.2-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Wed Jan 23 2019 Pete Walter <pwalter@fedoraproject.org> - 0.0.2-8
- Rebuild for ICU 63

* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 0.0.2-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Tue Jul 10 2018 Pete Walter <pwalter@fedoraproject.org> - 0.0.2-6
- Rebuild for ICU 62

* Mon Apr 30 2018 Pete Walter <pwalter@fedoraproject.org> - 0.0.2-5
- Rebuild for ICU 61.1

* Wed Feb 07 2018 Fedora Release Engineering <releng@fedoraproject.org> - 0.0.2-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Sat Feb 03 2018 Igor Gnatenko <ignatenkobrain@fedoraproject.org> - 0.0.2-3
- Switch to %%ldconfig_scriptlets

* Thu Nov 30 2017 Pete Walter <pwalter@fedoraproject.org> - 0.0.2-2
- Rebuild for ICU 60.1

* Thu Sep 14 2017 David Tardon <dtardon@redhat.com> - 0.0.2-1
- new upstream release

* Thu Aug 03 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.0.1-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.0.1-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Mon May 15 2017 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.0.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_27_Mass_Rebuild

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.0.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Wed Sep 07 2016 David Tardon <dtardon@redhat.com> - 0.0.1-1
- new upstream release

* Thu Jun 23 2016 David Tardon <dtardon@redhat.com> 0.0.0-1
- initial import
